@@ -12,13 +12,16 @@ import datetime
 from decimal import localcontext, Decimal
 from uuid import UUID
 
+import json
+
 from .six import (
     MemoryIO, xrange, btou, iteritems, is_str, str2ints, fstint
 )
 from .schema import (
-    extract_record_type, acquaint_schema, populate_schema_defs,
+    extract_record_type, extract_named_schemas_into_repo, populate_schema_defs,
     extract_logical_type
 )
+from ._schema_common import SCHEMA_DEFS
 from ._read_common import (
     SchemaResolutionError, MAGIC, SYNC_SIZE, HEADER_SCHEMA,
 )
@@ -27,11 +30,6 @@ from .const import (
     MLS_PER_SECOND, DAYS_SHIFT
 )
 
-try:
-    import ujson as json
-except ImportError:
-    import json
-
 MASK = 0xFF
 AVRO_TYPES = set([
     'boolean',
@@ -512,6 +510,16 @@ except ImportError:
     pass
 
 
+def acquaint_schema(schema):
+    """Extract schema into READERS"""
+    extract_named_schemas_into_repo(
+        schema,
+        READERS,
+        lambda schema: lambda fo, _, r_schema: read_data(
+            fo, schema, SCHEMA_DEFS.get(r_schema)),
+    )
+
+
 def _iter_avro(fo, header, codec, writer_schema, reader_schema):
     """Return iterator over avro records."""
     sync_marker = header['sync']
@@ -569,7 +577,7 @@ class iter_avro:
         self.codec = self.metadata.get('avro.codec', 'null')
         self.reader_schema = reader_schema
 
-        acquaint_schema(self.writer_schema, READERS)
+        acquaint_schema(self.writer_schema)
         if reader_schema:
             populate_schema_defs(reader_schema)
         self._records = _iter_avro(fo,
@@ -597,7 +605,7 @@ def schemaless_reader(fo, schema):
     schema: dict
         Reader schema
     """
-    acquaint_schema(schema, READERS)
+    acquaint_schema(schema)
     return read_data(fo, schema)
 
 
