@@ -6,10 +6,7 @@
 # http://svn.apache.org/viewvc/avro/trunk/lang/py/src/avro/ which is under
 # Apache 2.0 license (http://www.apache.org/licenses/LICENSE-2.0)
 
-try:
-    import ujson as json
-except ImportError:
-    import json
+import json
 
 import datetime
 import decimal
@@ -31,7 +28,7 @@ from .schema import (
     extract_named_schemas_into_repo, extract_record_type,
     extract_logical_type
 )
-from ._write_common import SCHEMA_DEFS
+from ._schema_common import SCHEMA_DEFS
 
 NoneType = type(None)
 
@@ -539,12 +536,11 @@ except ImportError:
     pass
 
 
-def acquaint_schema(schema, repo=None):
-    """Extract schema into repo (default WRITERS)"""
-    repo = WRITERS if repo is None else repo
+def acquaint_schema(schema):
+    """Extract schema into WRITERS"""
     extract_named_schemas_into_repo(
         schema,
-        repo,
+        WRITERS,
         lambda schema: lambda fo, datum, _: write_data(fo, datum, schema),
     )
     extract_named_schemas_into_repo(
